JmapChatExt

Trait JmapChatExt 

pub trait JmapChatExt {
    // Required method
    fn with_chat_session(&self, session: Session) -> SessionClient;
}
Extension trait adding JMAP Chat methods to jmap_base_client::JmapClient.

Import this trait to use: use jmap_chat_client::JmapChatExt;

All JMAP Chat method calls are made through the SessionClient returned by with_chat_session.

Required Methods

fn with_chat_session(&self, session: Session) -> SessionClient

Create a SessionClient bound to this client and session.

All JMAP Chat method calls are made through the returned SessionClient.

Implementations on Foreign Types

Source

impl JmapChatExt for JmapClient

Implementors